@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -79,8 +79,9 @@ public class LocaleNames_br extends OpenListResourceBundle {
         final String metaValue_te = "telougou";
         final String metaValue_th = "thai";
         final String metaValue_tl = "tagalog";
-        final String metaValue_frm = "krennc\u02bchalleg";
+        final String metaValue_chr = "cherokee";
         final String metaValue_vai = "vai";
+        final String metaValue_Hans = "eeunaet";
         final Object[][] data = new Object[][] {
             { "ksh", "koluneg" },
             { "Ogam", "ogam" },
@@ -91,6 +92,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "Zsye", "fromlunio\u00f9" },
             { "%%NJIVA", "rannyezh Gniva/Njiva" },
             { "xmf", "megreleg" },
+            { "ccp", "chakmaeg" },
             { "egy", "henegipteg" },
             { "raj", "rajasthani" },
             { "tem", "temne" },
@@ -149,6 +151,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "BY", "Belarus" },
             { "BZ", "Belize" },
             { "type.ca.persian", "deiziadur persek" },
+            { "%%CREISS", "rannyezho\u00f9 Creissent" },
             { "type.nu.hebr", "nivero\u00f9 hebraek" },
             { "CA", "Kanada" },
             { "CC", "Inizi Kokoz" },
@@ -210,7 +213,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "chm", "marieg" },
             { "chp", "chipewyan" },
             { "cho", "choktaw" },
-            { "chr", "cherokee" },
+            { "chr", metaValue_chr },
             { "ER", "Eritrea" },
             { "ES", "Spagn" },
             { "ET", "Etiopia" },
@@ -229,7 +232,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "FO", "Inizi Faero" },
             { "Taml", "tamilek" },
             { "FR", "Fra\u00f1s" },
-            { "%%SIMPLE", "SIMPLE" },
+            { "%%SIMPLE", metaValue_Hans },
             { "pcd", "pikardeg" },
             { "tkl", "tokelau" },
             { "grb", "grebo" },
@@ -266,6 +269,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "GY", "Guyana" },
             { "ckb", "kurdeg sorani" },
             { "zxx", "diyezh" },
+            { "%%VIVARAUP", "vivaroalpeg" },
             { "de_AT", "alamaneg Aostria" },
             { "Vaii", metaValue_vai },
             { "HK", "Hong Kong RMD Sina" },
@@ -302,7 +306,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "Zmth", "notadur jedoniel" },
             { "type.nu.thai", "sifro\u00f9 thai" },
             { "vro", "voroeg" },
-            { "%%POSIX", "POSIX" },
+            { "%%POSIX", "stlenneg" },
             { "type.nu.beng", "sifro\u00f9 bengali" },
             { "type.nu.cyrl", "nivero\u00f9 kirillek" },
             { "JE", "Jerzenez" },
@@ -311,10 +315,10 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "JM", "Jamaika" },
             { "%%EKAVSK", "serbeg gant distagadur ekavian" },
             { "JO", "Jordania" },
-            { "%%1606NICT", metaValue_frm },
             { "JP", "Japan" },
+            { "%%1606NICT", "krennc\u02bchalleg diwezha\u00f1" },
             { "ain", "ainoueg" },
-            { "%%KOCIEWIE", "Kociewie" },
+            { "%%KOCIEWIE", "rannyezh polonek Kociewie" },
             { "guz", "gusiieg" },
             { "tog", "nyasa tonga" },
             { "type.nu.knda", "sifro\u00f9 kanarek" },
@@ -328,6 +332,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "KM", "Komorez" },
             { "KN", "Saint Kitts ha Nevis" },
             { "Knda", "kannada" },
+            { "Zinh", "h\u00earezh" },
             { "fr_CA", "galleg Kanada" },
             { "KP", "Korea an Norzh" },
             { "KR", "Korea ar Su" },
@@ -374,7 +379,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "MH", "Inizi Marshall" },
             { "ale", "aleouteg" },
             { "type.nu.vaii", "sifro\u00f9 vai" },
-            { "MK", "Makedonia" },
+            { "MK", "Makedonia an Norzh" },
             { "ML", "Mali" },
             { "MM", "Myanmar (Birmania)" },
             { "MN", "Mongolia" },
@@ -395,6 +400,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "MY", "Malaysia" },
             { "MZ", "Mozambik" },
             { "NA", "Namibia" },
+            { "%%ARANES", "araneg" },
             { "202", "Afrika issaharat" },
             { "type.ca.hebrew", "deiziadur hebraek" },
             { "type.co.dictionary", "urzh rumma\u00f1 ar geriadur" },
@@ -412,6 +418,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "NP", "Nepal" },
             { "NR", "Nauru" },
             { "NU", "Niue" },
+            { "Phnx", "fenikianek" },
             { "rof", "rombo" },
             { "tsi", "tsimshian" },
             { "NZ", "Zeland-Nevez" },
@@ -419,6 +426,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "rom", "romanieg" },
             { "crh", "turkeg Krimea" },
             { "ang", "hensaozneg" },
+            { "%%GRMISTR", "skritur okitanek mistralek" },
             { "OM", "Oman" },
             { "%%PETR1708", "reizhskrivadur rusianek 1708 P\u00ear I" },
             { "anp", "angika" },
@@ -433,6 +441,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "PG", "Papoua Ginea-Nevez" },
             { "PH", "Filipinez" },
             { "PK", "Pakistan" },
+            { "%%NICARD", "nisardeg" },
             { "PL", "Polonia" },
             { "ewo", "ewondo" },
             { "PM", "Sant-P\u00ear-ha-Mikelon" },
@@ -474,6 +483,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "RU", "Rusia" },
             { "RW", "Rwanda" },
             { "%%METELKO", "lizherenneg Metelko" },
+            { "Mani", "manikeek" },
             { "Ugar", "ougaritek" },
             { "SA", "Arabia Saoudat" },
             { "pon", "pohnpei" },
@@ -512,7 +522,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "SX", "Sint Maarten" },
             { "SY", "Siria" },
             { "yao", "yao" },
-            { "SZ", "Swaziland" },
+            { "SZ", "Eswatini" },
             { "arw", "arawakeg" },
             { "arz", "arabeg Egipt" },
             { "ary", "arabeg Maroko" },
@@ -565,6 +575,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "US", "Stado\u00f9-Unanet" },
             { "haw", "hawaieg" },
             { "%%1959ACAD", "belaruseg akademek" },
+            { "%%IVANCHOV", "reizhskrivadur bulgarek Ivanchov" },
             { "type.co.gb2312han", "urzh rumma\u00f1 sinaek eeunaet - GB2312" },
             { "UY", "Uruguay" },
             { "prg", "henbruseg" },
@@ -579,6 +590,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "VE", "Venezuela" },
             { "VG", "Inizi Gwerc\u02bch Breizh-Veur" },
             { "VI", "Inizi Gwerc\u02bch ar Stado\u00f9-Unanet" },
+            { "%%LEMOSIN", "rannyezh Limousin" },
             { "VN", "Vi\u00eat Nam" },
             { "VU", "Vanuatu" },
             { "nog", "nogay" },
@@ -599,7 +611,9 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "type.nu.mtei", "sifro\u00f9 meitei mayek" },
             { "wal", "walamo" },
             { "was", "washo" },
+            { "XA", "pouez-mouezh gaou" },
             { "war", "waray" },
+            { "XB", "BiDi gaou" },
             { "awa", "awadhi" },
             { "061", "Polinezia" },
             { "%%KSCOR", "kerneveureg standart" },
@@ -607,6 +621,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "type.nu.brah", "sifro\u00f9 brahmi" },
             { "Gujr", metaValue_gu },
             { "Zxxx", "anskrivet" },
+            { "Batk", "batak" },
             { "YE", "Yemen" },
             { "nqo", "nkoeg" },
             { "type.co.standard", "urzh rumma\u00f1 standart" },
@@ -636,7 +651,9 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "type.nu.telu", "sifro\u00f9 telougou" },
             { "lou", "kreoleg Louiziana" },
             { "loz", "lozi" },
+            { "%%FONKIRSH", "lizherenneg fonetek Kirshenbaum" },
             { "%%ASANTE", "achanti" },
+            { "%%AUVERN", "arverneg" },
             { "jmc", "machame" },
             { "type.nu.hansfin", "nivero\u00f9 sinaek eeunaet an arc\u02bchant" },
             { "hil", "hiligaynon" },
@@ -653,7 +670,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "nwc", "newari klasel" },
             { "udm", "oudmourteg" },
             { "Khmr", metaValue_km },
-            { "%%FONNAPA", "FONNAPA" },
+            { "%%FONNAPA", "lizherenneg fonetek Norzh Amerika" },
             { "type.ca.islamic-rgsa", "deiziadur islamek (Arabia Saoudat)" },
             { "sad", "sandawe" },
             { "type.nu.roman", "nivero\u00f9 roman" },
@@ -671,6 +688,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "%%BISCAYAN", "rannyezh euskarek Bizkaia" },
             { "sbp", "sangu" },
             { "lui", "luiseno" },
+            { "%%GRITAL", "skritur okitanek Italia" },
             { "nyn", "nyankole" },
             { "nym", "nyamwezi" },
             { "lun", "lunda" },
@@ -683,6 +701,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "bal", "baloutchi" },
             { "ban", "balineg" },
             { "uga", "ougariteg" },
+            { "type.nu.wara", "sifro\u00f9 warang" },
             { "fit", "finneg trao\u00f1ienn an Torne" },
             { "luy", "luyia" },
             { "bar", "bavarieg" },
@@ -710,6 +729,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "av", "avar" },
             { "ay", "aymara" },
             { "az", "azerbaidjaneg" },
+            { "%%CISAUP", "kizalpeg" },
             { "%%OSOJS", "rannyezh Oseacco/Osojane" },
             { "%%UNIFON", "lizherenneg fonetek Unifon" },
             { "ba", "bachkir" },
@@ -769,13 +789,14 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "Hanb", "han gant bopomofo" },
             { "eu", "euskareg" },
             { "Hang", "hangeul" },
+            { "Samr", "samaritek" },
             { "shi", "tacheliteg" },
             { "hsb", "uhelsorabeg" },
-            { "Hani", "han" },
+            { "Hani", "sinalunio\u00f9 (han)" },
             { "%%ULSTER", "rannyezh skotek Ulad" },
             { "shn", "shan" },
             { "fa", "perseg" },
-            { "Hans", "eeunaet" },
+            { "Hans", metaValue_Hans },
             { "type.nu.latn", "sifro\u00f9 arabek ar C\u02bchorn\u00f4g" },
             { "Hant", "hengounel" },
             { "ff", "fula" },
@@ -822,9 +843,10 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "id", "indonezeg" },
             { "type.nu.tibt", "sifro\u00f9 tibetan" },
             { "ie", "interlingue" },
+            { "%%GASCON", "gwaskoneg" },
             { "ig", "igbo" },
-            { "frm", metaValue_frm },
             { "ii", "yieg Sichuan" },
+            { "frm", "krennc\u02bchalleg" },
             { "%%RUMGR", "roma\u00f1cheg Grischun" },
             { "%%AO1990", "emglev 1990 war ar reizhskrivadur portugalek" },
             { "ik", "inupiaq" },
@@ -840,6 +862,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "%%HOGNORSK", "uhelnorvegeg" },
             { "Mlym", metaValue_ml },
             { "ja", "japaneg" },
+            { "Sarb", "henarabek ar Su" },
             { "doi", "dogri" },
             { "type.nu.lepc", "sifro\u00f9 lepcha" },
             { "sma", "s\u00e1mi ar Su" },
@@ -913,6 +936,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "nl", "nederlandeg" },
             { "nn", "norvegeg nynorsk" },
             { "no", "norvegeg" },
+            { "%%PROVENC", "prova\u00f1seg" },
             { "nr", "ndebele ar Su" },
             { "nv", "navac\u02bcho" },
             { "kaa", "karakalpak" },
@@ -989,6 +1013,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "mic", "mikmakeg" },
             { "suk", "sukuma" },
             { "en_AU", "saozneg Aostralia" },
+            { "Dupl", "berrskriverezh Duploy\u00e9" },
             { "sa", "sanskriteg" },
             { "%%UCCOR", "kerneveureg unvan" },
             { "sc", "sardeg" },
@@ -1016,6 +1041,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "%%NEDIS", "rannyezh Natisone" },
             { "sv", "svedeg" },
             { "sw", "swahili" },
+            { "type.nu.wcho", "sifro\u00f9 wantcho" },
             { "type.nu.hantfin", "nivero\u00f9 sinaek hengounel an arc\u02bchant" },
             { "ibb", "ibibio" },
             { "iba", "iban" },
@@ -1027,7 +1053,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "145", "Azia ar C\u02bchorn\u00f4g" },
             { "tg", "tadjik" },
             { "th", metaValue_th },
-            { "%%SPANGLIS", "SPANGLIS" },
+            { "%%SPANGLIS", "spanglish" },
             { "ti", "tigrigna" },
             { "bug", "bugi" },
             { "kfo", "koroeg" },
@@ -1041,6 +1067,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "tr", "turkeg" },
             { "ts", "tsonga" },
             { "swb", "komoreg" },
+            { "Cakm", "chakmaek" },
             { "tt", "tatar" },
             { "%%XSISTEMO", "esperanteg sistem X" },
             { "dyu", "dyula" },
@@ -1084,9 +1111,12 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "syr", "sirieg" },
             { "Grek", "gresianek" },
             { "gan", "sinaeg Gan" },
+            { "Lydi", "lidiek" },
+            { "Xsux", "gennhe\u00f1vel" },
             { "wo", "wolof" },
             { "zgh", "tamacheg Maroko standart" },
             { "ar_001", "arabeg modern" },
+            { "Cans", "silabennaoueg engenidik unvan Kanada" },
             { "%%FONXSAMP", "treuzskrivadur X-SAMPA" },
             { "gay", "gayo" },
             { "Mong", "mongolek" },
@@ -1103,6 +1133,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "type.nu.romanlow", "nivero\u00f9 roman bihan" },
             { "byn", "blin" },
             { "%%PAMAKA", "rannyezh Pamaka" },
+            { "Lyci", "likiek" },
             { "osa", "osage" },
             { "moh", "mohawk" },
             { "kkj", "kakoeg" },
@@ -1124,12 +1155,15 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "type.co.phonebook", "urzh rumma\u00f1 al levr-pellgomz" },
             { "%%MONOTON", "gresianeg untonel" },
             { "Geor", "jorjianek" },
+            { "%%LENGADOC", "lengadokeg" },
             { "kmb", "kimbundu" },
             { "type.nu.jpanfin", "nivero\u00f9 japanek an arc\u02bchant" },
+            { "Cham", "cham" },
             { "gez", "gezeg" },
             { "mrj", "marieg ar C\u02bchorn\u00f4g" },
             { "Syrn", "siriek ar Reter" },
             { "type.nu.mymrshan", "sifro\u00f9 shan Myanmar" },
+            { "Narb", "henarabek an Norzh" },
             { "type.nu.olck", "sifro\u00f9 ol chiki" },
             { "type.co.reformed", "urzh rumma\u00f1 adreizhet" },
             { "Tglg", metaValue_tl },
@@ -1137,21 +1171,24 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "ebu", "embu" },
             { "Egyp", "hieroglifo\u00f9 egiptek" },
             { "zh_Hans", "sinaeg eeunaet" },
+            { "Hung", "henhungarek" },
             { "kok", "konkani" },
             { "%%1901", "reizhskrivadur alamanek hengounel" },
             { "kos", "kosrae" },
             { "vec", "venezieg" },
-            { "%%PAHAWH2", "PAHAWH2" },
-            { "%%PAHAWH3", "PAHAWH3" },
-            { "%%PAHAWH4", "PAHAWH4" },
+            { "%%PAHAWH2", "reizhskrivadur pahawh hmong lankad 2" },
+            { "%%PAHAWH3", "reizhskrivadur pahawh hmong lankad 3" },
+            { "%%PAHAWH4", "reizhskrivadur pahawh hmong doare diwezha\u00f1" },
             { "type.nu.limb", "sifro\u00f9 limbu" },
             { "zh_Hant", "sinaeg hengounel" },
             { "Sund", "sundanek" },
             { "vep", "vepseg" },
             { "kpe", "kpelle" },
+            { "%%GRCLASS", "skritur okitanek klasel" },
             { "type.nu.khmr", "sifro\u00f9 khmer" },
             { "ilo", "ilokanoeg" },
             { "%%VALENCIA", "valensianeg" },
+            { "Cprt", "silabennaoueg kipriek" },
             { "%%BAKU1926", "lizherenneg latin turkek unvan" },
             { "%%IJEKAVSK", "serbeg gant distagadur ijekavian" },
             { "mua", "moundangeg" },
@@ -1164,6 +1201,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "Glag", "glagolitek" },
             { "gil", "gilberteg" },
             { "%%KKCOR", "kerneveureg kumun" },
+            { "Cher", metaValue_chr },
             { "car", "karibeg" },
             { "type.nu.tamldec", "sifro\u00f9 tamilek" },
             { "krc", "karatchay-balkar" },
